==> haskell-cryptohash-cryptoapi-0.1.4-60-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-cryptohash-cryptoapi.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cryptohash-cryptoapi
version: 0.1.4
id: cryptohash-cryptoapi-0.1.4-DMZrwu8N3By1XJDhwBzBDW
key: cryptohash-cryptoapi-0.1.4-DMZrwu8N3By1XJDhwBzBDW
license: BSD-3-Clause
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
author: Vincent Hanquez <vincent@snarc.org>
homepage: https://github.com/vincenthz/hs-cryptohash-cryptoapi
synopsis: Crypto-api interfaces for cryptohash
description:
    Crypto-api interfaces for cryptohash
category: Cryptography
abi: 27821e96e7e8e8553cd46432c4e5c316
exposed: True
exposed-modules:
    Crypto.Hash.CryptoAPI
import-dirs: /usr/lib/ghc-8.6.5/site-local/cryptohash-cryptoapi-0.1.4
library-dirs: /usr/lib/ghc-8.6.5/site-local/cryptohash-cryptoapi-0.1.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/cryptohash-cryptoapi-0.1.4
hs-libraries: HScryptohash-cryptoapi-0.1.4-DMZrwu8N3By1XJDhwBzBDW
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    cereal-0.5.8.1-7AyRb7vLva5K85rZXh3kQh
    crypto-api-0.13.3-ALzE3By8BvHGVvnn2irh7V
    cryptonite-0.26-CDY1m3syfqq9pANhaEyZh6
    memory-0.14.18-2FfCNwP2nzn4wBPtrz4oOB
    tagged-0.8.6-AoE7RQX12AwJxLvAxGYxtP
haddock-interfaces: /usr/share/doc/haskell-cryptohash-cryptoapi/html/cryptohash-cryptoapi.haddock
haddock-html: /usr/share/doc/haskell-cryptohash-cryptoapi/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cryptohash-cryptoapi-0.1.4-64-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-cryptohash-cryptoapi.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cryptohash-cryptoapi
version: 0.1.4
id: cryptohash-cryptoapi-0.1.4-uBxsHSQ697LgWw7SvhNHC
key: cryptohash-cryptoapi-0.1.4-uBxsHSQ697LgWw7SvhNHC
license: BSD-3-Clause
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
author: Vincent Hanquez <vincent@snarc.org>
homepage: https://github.com/vincenthz/hs-cryptohash-cryptoapi
synopsis: Crypto-api interfaces for cryptohash
description:
    Crypto-api interfaces for cryptohash
category: Cryptography
abi: c55f765ebe0622ac11233b9ffb97b5af
exposed: True
exposed-modules:
    Crypto.Hash.CryptoAPI
import-dirs: /usr/lib/ghc-8.6.5/site-local/cryptohash-cryptoapi-0.1.4
library-dirs: /usr/lib/ghc-8.6.5/site-local/cryptohash-cryptoapi-0.1.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/cryptohash-cryptoapi-0.1.4
hs-libraries: HScryptohash-cryptoapi-0.1.4-uBxsHSQ697LgWw7SvhNHC
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    cereal-0.5.8.1-7AyRb7vLva5K85rZXh3kQh
    crypto-api-0.13.3-Bqlv92FAlG0F3d21zytrBM
    cryptonite-0.26-CDY1m3syfqq9pANhaEyZh6
    memory-0.14.18-2FfCNwP2nzn4wBPtrz4oOB
    tagged-0.8.6-AoE7RQX12AwJxLvAxGYxtP
haddock-interfaces: /usr/share/doc/haskell-cryptohash-cryptoapi/html/cryptohash-cryptoapi.haddock
haddock-html: /usr/share/doc/haskell-cryptohash-cryptoapi/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
